==> lxqt-about_0.17.0.orig.tar.xz: lxqt-about-0.17.0/translations/lxqt-about_si.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="si">
<context>
    <name>AboutDialogPrivate</name>
    <message>
        <location filename="../aboutdialog/lxqtaboutdialog.cpp" line="83"/>
        <source>Version: %1</source>
        <translation>අනුවාදය: %1</translation>
    </message>
    <message>
        <location filename="../aboutdialog/lxqtaboutdialog.cpp" line="96"/>
        <source>Advanced, easy-to-use, and fast desktop environment based on Qt technologies.</source>
        <comment>About dialog, &apos;About&apos; tab text</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../aboutdialog/lxqtaboutdialog.cpp" line="98"/>
        <source>LXQt would not have been possible without the &lt;a %1&gt;Razor-qt&lt;/a&gt; project and its many contributors.</source>
        <comment>About dialog, &apos;About&apos; tab text</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../aboutdialog/lxqtaboutdialog.cpp" line="100"/>
        <source>Copyright: © %1-%2 %3</source>
        <comment>About dialog, &apos;About&apos; tab text</comment>
        <translation>ප්‍රකාශන හිමිකම: © %1-%2 %3</translation>
    </message>
    <message>
        <location filename="../aboutdialog/lxqtaboutdialog.cpp" line="102"/>
        <source>Homepage: %1</source>
        <comment>About dialog, &apos;About&apos; tab text</comment>
        <translation>මුල් පිටුව: %1</translation>
    </message>
    <message>
        <location filename="../aboutdialog/lxqtaboutdialog.cpp" line="104"/>
        <source>License: %1</source>
        <comment>About dialog, &apos;About&apos; tab text</comment>
        <translation>බලපත්‍රය: %1</translation>
    </message>
    <message>
        <location filename="../aboutdialog/lxqtaboutdialog.cpp" line="114"/>
        <source>LXQt is developed by the &lt;a %1&gt;LXQt Team and contributors&lt;/a&gt;.</source>
        <comment>About dialog, &apos;Authors&apos; tab text</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../aboutdialog/lxqtaboutdialog.cpp" line="116"/>
        <source>If you are interested in working with our development team, &lt;a %1&gt;join us&lt;/a&gt;.</source>
        <comment>About dialog, &apos;Authors&apos; tab text</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../aboutdialog/lxqtaboutdialog.cpp" line="133"/>
        <source>Special thanks to:</source>
        <comment>About dialog, &apos;Thanks&apos; tab text</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../aboutdialog/lxqtaboutdialog.cpp" line="140"/>
        <source>LXQt is translated into many languages thanks to the work of the translation teams all over the world. Translations can be done in &lt;a %1&gt;LXQt-Weblate&lt;/a&gt;.</source>
        <comment>About dialog, &apos;Translations&apos; tab text</comment>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>about</name>
    <message>
        <location filename="../aboutdialog/lxqtaboutdialog.ui" line="165"/>
        <location filename="../build/lxqt-about_autogen/include/ui_lxqtaboutdialog.h" line="194"/>
        <source>Copy to clipboard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../aboutdialog/lxqtaboutdialog.ui" line="14"/>
        <location filename="../build/lxqt-about_autogen/include/ui_lxqtaboutdialog.h" line="189"/>
        <source>About LXQt</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../aboutdialog/lxqtaboutdialog.ui" line="66"/>
        <location filename="../build/lxqt-about_autogen/include/ui_lxqtaboutdialog.h" line="190"/>
        <source>About</source>
        <comment>About dialog, Tab title </comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../aboutdialog/lxqtaboutdialog.ui" line="83"/>
        <location filename="../build/lxqt-about_autogen/include/ui_lxqtaboutdialog.h" line="191"/>
        <source>Authors</source>
        <comment>About dialog, Tab title</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../aboutdialog/lxqtaboutdialog.ui" line="100"/>
        <location filename="../build/lxqt-about_autogen/include/ui_lxqtaboutdialog.h" line="192"/>
        <source>Thanks</source>
        <comment>About dialog, Tab title</comment>
        <translation>ස්තූතියි</translation>
    </message>
    <message>
        <location filename="../aboutdialog/lxqtaboutdialog.ui" line="117"/>
        <location filename="../build/lxqt-about_autogen/include/ui_lxqtaboutdialog.h" line="193"/>
        <source>Translations</source>
        <comment>About dialog, Tab title</comment>
        <translation>පරිවර්තන</translation>
    </message>
    <message>
        <location filename="../aboutdialog/lxqtaboutdialog.ui" line="134"/>
        <location filename="../build/lxqt-about_autogen/include/ui_lxqtaboutdialog.h" line="195"/>
        <source>Technical Info</source>
        <comment>About dialog, Tab title</comment>
        <translation>තාක්ෂණික තොරතුරු</translation>
    </message>
</context>
</TS>

==> lxqt-about_1.1.0.orig.tar.xz: lxqt-about-1.1.0/translations/lxqt-about_si.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="si">
<context>
    <name>AboutDialogPrivate</name>
    <message>
        <location filename="../aboutdialog/lxqtaboutdialog.cpp" line="83"/>
        <source>Version: %1</source>
        <translation>අනුවාදය: %1</translation>
    </message>
    <message>
        <location filename="../aboutdialog/lxqtaboutdialog.cpp" line="99"/>
        <source>Advanced, easy-to-use, and fast desktop environment based on Qt technologies.</source>
        <comment>About dialog, &apos;About&apos; tab text</comment>
        <translation>භාවිතයට පහසු, උසස්, Qt තාක්ෂණයන් පදනම් කරගත් වේගවත් ඩෙස්ක්ටොප් පරිසරය.</translation>
    </message>
    <message>
        <location filename="../aboutdialog/lxqtaboutdialog.cpp" line="101"/>
        <source>LXQt would not have been possible without the &lt;a %1&gt;Razor-qt&lt;/a&gt; project and its many contributors.</source>
        <comment>About dialog, &apos;About&apos; tab text</comment>
        <translation>&lt;a %1&gt;Razor-qt&lt;/a&gt; ව්‍යාපෘතිය සහ එහි බොහෝ දායකයින් නොමැතිව LXQt නිර්මාණය කළ නොහැකි වනු ඇත.</translation>
    </message>
    <message>
        <location filename="../aboutdialog/lxqtaboutdialog.cpp" line="103"/>
        <source>Copyright: © %1-%2 %3</source>
        <comment>About dialog, &apos;About&apos; tab text</comment>
        <translation>ප්‍රකාශන හිමිකම: © %1-%2 %3</translation>
    </message>
    <message>
        <location filename="../aboutdialog/lxqtaboutdialog.cpp" line="105"/>
        <source>Homepage: %1</source>
        <comment>About dialog, &apos;About&apos; tab text</comment>
        <translation>මුල් පිටුව: %1</translation>
    </message>
    <message>
        <location filename="../aboutdialog/lxqtaboutdialog.cpp" line="107"/>
        <source>Wiki: %1</source>
        <comment>About dialog, &apos;About&apos; tab text</comment>
        <translation>විකී: %1</translation>
    </message>
    <message>
        <location filename="../aboutdialog/lxqtaboutdialog.cpp" line="109"/>
        <source>Development: %1</source>
        <comment>About dialog, &apos;About&apos; tab text</comment>
        <translation>සංවර්ධනය: %1</translation>
    </message>
    <message>
        <location filename="../aboutdialog/lxqtaboutdialog.cpp" line="111"/>
        <source>License: %1</source>
        <comment>About dialog, &apos;About&apos; tab text</comment>
        <translation>බලපත්‍රය: %1</translation>
    </message>
    <message>
        <location filename="../aboutdialog/lxqtaboutdialog.cpp" line="121"/>
        <source>LXQt is developed by the &lt;a %1&gt;LXQt Team and contributors&lt;/a&gt;.</source>
        <comment>About dialog, &apos;Authors&apos; tab text</comment>
        <translation>LXQt නිර්මාණය කර ඇත්තේ &lt;a %1&gt;LXQt කණ්ඩායම සහ දායකයින්&lt;/a&gt; විසිනි.</translation>
    </message>
    <message>
        <location filename="../aboutdialog/lxqtaboutdialog.cpp" line="123"/>
        <source>If you are interested in working with our development team, &lt;a %1&gt;join us&lt;/a&gt;.</source>
        <comment>About dialog, &apos;Authors&apos; tab text</comment>
        <translation>ඔබ අපගේ සංවර්ධන කණ්ඩායම සමඟ වැඩ කිරීමට කැමති නම්, &lt;a %1&gt;අපට එකතු වන්න&lt;/a&gt;.</translation>
    </message>
    <message>
        <location filename="../aboutdialog/lxqtaboutdialog.cpp" line="140"/>
        <source>Special thanks to:</source>
        <comment>About dialog, &apos;Thanks&apos; tab text</comment>
        <translation>විශේෂ ස්තුතිය:</translation>
    </message>
    <message>
        <location filename="../aboutdialog/lxqtaboutdialog.cpp" line="147"/>
        <source>LXQt is translated into many languages thanks to the work of the translation teams all over the world. Translations can be done in &lt;a %1&gt;LXQt-Weblate&lt;/a&gt;.</source>
        <comment>About dialog, &apos;Translations&apos; tab text</comment>
        <translation>LXQt, ලොව පුරා පරිවර්තන කණ්ඩායම්වලට ස්තූතිවන්ත වන්න, බොහෝ භාෂාවලට පරිවර්තනය කර ඇත. පරිවර්තන &lt;a %1&gt;LXQt වෙබ් අඩවිය&lt;/a&gt; මගින් සිදුකල හැක.</translation>
    </message>
</context>
<context>
    <name>about</name>
    <message>
        <location filename="../aboutdialog/lxqtaboutdialog.ui" line="165"/>
        <source>Copy to clipboard</source>
        <translation>clipboard වෙතට පිටපත් කරන්න</translation>
    </message>
    <message>
        <location filename="../aboutdialog/lxqtaboutdialog.ui" line="14"/>
        <source>About LXQt</source>
        <translation>LXQt පිලිබඳ</translation>
    </message>
    <message>
        <location filename="../aboutdialog/lxqtaboutdialog.ui" line="66"/>
        <source>About</source>
        <comment>About dialog, Tab title </comment>
        <translation>පිලිබඳ</translation>
    </message>
    <message>
        <location filename="../aboutdialog/lxqtaboutdialog.ui" line="83"/>
        <source>Authors</source>
        <comment>About dialog, Tab title</comment>
        <translation>කතුවරුන්</translation>
    </message>
    <message>
        <location filename="../aboutdialog/lxqtaboutdialog.ui" line="100"/>
        <source>Thanks</source>
        <comment>About dialog, Tab title</comment>
        <translation>ස්තූතියි</translation>
    </message>
    <message>
        <location filename="../aboutdialog/lxqtaboutdialog.ui" line="117"/>
        <source>Translations</source>
        <comment>About dialog, Tab title</comment>
        <translation>පරිවර්තන</translation>
    </message>
    <message>
        <location filename="../aboutdialog/lxqtaboutdialog.ui" line="134"/>
        <source>Technical Info</source>
        <comment>About dialog, Tab title</comment>
        <translation>තාක්ෂණික තොරතුරු</translation>
    </message>
</context>
</TS>
